@@ -1,5 +1,5 @@
-#  tests for pyproj-3.0.0.post1-py38h0ae89ba_0 (this is a generated file);
-print('===== testing package: pyproj-3.0.0.post1-py38h0ae89ba_0 =====');
+#  tests for pyproj-3.0.1-py38h0ae89ba_0 (this is a generated file);
+print('===== testing package: pyproj-3.0.1-py38h0ae89ba_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import os
@@ -16,7 +16,7 @@ if not os.path.isdir(pyproj.datadir.get_data_dir()):
     sys.exit(1)
 #  --- run_test.py (end) ---
 
-print('===== pyproj-3.0.0.post1-py38h0ae89ba_0 OK =====');
+print('===== pyproj-3.0.1-py38h0ae89ba_0 OK =====');
 print("import: 'pyproj'")
 import pyproj
 
